# Shaper

[![License](https://img.shields.io/badge/license-Apache-green.svg?style=flat)](https://raw.githubusercontent.com/arno49/shaper/master/LICENSE)
[![Total alerts](https://img.shields.io/lgtm/alerts/g/arno49/shaper.svg?logo=lgtm&logoWidth=18)](https://lgtm.com/projects/g/arno49/shaper/alerts/)
[![Language grade: Python](https://img.shields.io/lgtm/grade/python/g/arno49/shaper.svg?logo=lgtm&logoWidth=18)](https://lgtm.com/projects/g/arno49/shaper/context:python)
[![codecov](https://codecov.io/gh/arno49/shaper/branch/master/graph/badge.svg)](https://codecov.io/gh/arno49/shaper)
[![Build Status](https://travis-ci.org/arno49/shaper.svg?branch=master)](https://travis-ci.org/arno49/shaper)
Tool for render configurations from few templates/sources.

## Getting Started

These instructions will get you a copy of the project up and running on your local machine for development and testing purposes. See deployment for notes on how to deploy the project on a live system.


### Installing

A step by step series of examples that tell you how to get a development env running

Say what the step will be

```
# pip install shaper
```


End with an example of getting some data out of the system or using it for a little demo

## Running the tests

TBD

### And coding style tests

TBD

## Contributing

TBD

## Versioning

We use [versioneer](https://pypi.org/project/versioneer/) for versioning. For the versions available, see the [tags on this repository](https://github.com/arno49/shaper/tags). 

## Authors

* **Ivan Bogomazov** - [arno49](https://github.com/arno49)

See also the list of [contributors](https://github.com/your/project/contributors) who participated in this project.

## License

This project is licensed under the Apache 2.0 - see the [LICENSE](LICENSE) file for details

